@@ -65,28 +65,35 @@ int main( int argc, char *argv[] )
 // dialog to setup screen saver parameters
 //
 KGravitySetup::KGravitySetup( QWidget *parent )
-	 : QDialog(parent)
+	 : KDialog(parent)
 {
-	setupUi(this);
+
+        setCaption(i18n( "Gravity Setup" ));
+        setButtons(Ok|Cancel|Help);
+        setDefaultButton(Ok);
+        setModal(true);
+        setButtonText( Help, i18n( "A&bout" ) );
+        QWidget *main = new QWidget(this);
+        setMainWidget(main);
+        cfg = new GravityWidget(main);
+        connect(this,SIGNAL(okClicked()),this,SLOT(slotOkPressed()));
+        connect(this,SIGNAL(helpClicked()),this,SLOT(aboutPressed()));
 	readSettings();
 
-	preview->setFixedSize( 220, 170 );
+	cfg->preview->setFixedSize( 220, 170 );
         {
             QPalette palette;
-            palette.setColor( preview->backgroundRole(), Qt::black );
-            preview->setPalette( palette );
-	    preview->setAutoFillBackground(true);
+            palette.setColor( cfg->preview->backgroundRole(), Qt::black );
+            cfg->preview->setPalette( palette );
+	    cfg->preview->setAutoFillBackground(true);
         }
 #ifdef Q_WS_X11
-	preview->show();    // otherwise saver does not get correct size
+	cfg->preview->show();    // otherwise saver does not get correct size
 #endif
-	saver = new KGravitySaver( preview->winId() );
+	saver = new KGravitySaver( cfg->preview->winId() );
 ;
-	connect( PushButton1, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-	connect( PushButton2, SIGNAL( clicked() ), SLOT( reject() ) );
-	connect( PushButton3, SIGNAL( clicked() ), SLOT( aboutPressed() ) );
-	connect(  SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
-	connect( RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
+	connect(  cfg->SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
+	connect( cfg->RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
 
 }
 
@@ -103,16 +110,13 @@ void KGravitySetup::readSettings()
 
 	bool boolval = grp.readEntry( "Stars", false );
 	if (boolval) {
-		RadioButton1->setChecked(true);
+            cfg->RadioButton1->setChecked(true);
 	} else {
-		if (!boolval)
-		{
-			RadioButton1_2->setChecked(true);
-		}
+            cfg->RadioButton1_2->setChecked(true);
 	}
 
 	int starammount = grp.readEntry("StarSize", 75);
-	SpinBox1->setValue(starammount);
+	cfg->SpinBox1->setValue(starammount);
 
 }
 
@@ -122,16 +126,16 @@ void KGravitySetup::slotOkPressed()
 	KConfig _config("kssgravityrc", KConfig::NoGlobals);
 	KConfigGroup config(&_config, "Settings" );
 
-	if (RadioButton1->isChecked() == true)
+	if (cfg->RadioButton1->isChecked())
 	{
 		config.writeEntry( "Stars", true );
 	} else {
-		if (RadioButton1_2->isChecked() == true)
+		if (cfg->RadioButton1_2->isChecked() == true)
 		{
 			config.writeEntry( "Stars", false );
 		}
 	}
-	config.writeEntry( "StarSize", SpinBox1->value() );
+	config.writeEntry( "StarSize", cfg->SpinBox1->value() );
 
 	config.sync();
 
