@@ -48,7 +48,7 @@ const bool DEFAULT_KEEP_CENTERED = false;
 class KClockSaverInterface : public KScreenSaverInterface {
 public:
 	virtual KAboutData *aboutData() {
-		return new KAboutData("kclock.kss", 0, ki18n("Clock"), "2.0", ki18n("Clock"));
+		return new KAboutData("kclock.kss", "klock", ki18n("Clock"), "2.0", ki18n("Clock"));
 	}
 
 	virtual KScreenSaver *create(WId id) {
