@@ -2,7 +2,25 @@
 kwin - the KDE window manager
 								
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************/
+
 #include "kde1client.h"
 #include <qcursor.h>
 #include <qlayout.h>
@@ -305,7 +323,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
               case 'M': // Menu button
                   if (!button[ButtonMenu]) {
                       button[ButtonMenu] = new QToolButton( widget(), 0 );
-                      QToolTip::add( button[ButtonMenu], i18n("Menu") );
+                      button[ButtonMenu]->setToolTip( i18n("Menu") );
                       button[ButtonMenu]->setCursor(ArrowCursor);
                       if( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
                           button[ButtonMenu]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
@@ -320,7 +338,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
                   if (!button[ButtonSticky]) {
                      button[ButtonSticky] = new QToolButton( widget(), 0 );
                      button[ButtonSticky]->setIconSet( isOnAllDesktops()?*pindown_pix:*pinup_pix );
-                     QToolTip::add( button[ButtonSticky], isOnAllDesktops()?i18n("Not On All Desktops"):i18n("On All Desktops")  );
+                     button[ButtonSticky]->setToolTip( isOnAllDesktops()?i18n("Not On All Desktops"):i18n("On All Desktops")  );
                      button[ButtonSticky]->setCursor(ArrowCursor);
                      button[ButtonSticky]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
                                                       isActive() ? *pinup_pix : *dis_pinup_pix );
@@ -332,7 +350,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
               case 'H': // Help button
                   if ((!button[ButtonHelp]) && providesContextHelp()) {
                       button[ButtonHelp] = new QToolButton( widget(), 0 );
-                      QToolTip::add( button[ButtonHelp], i18n("Help") );
+                      button[ButtonHelp]->setToolTip( i18n("Help") );
                       button[ButtonHelp]->setIconSet( isActive() ? *question_mark_pix : *dis_question_mark_pix);
                       connect( button[ButtonHelp], SIGNAL( clicked() ), this, ( SLOT( showContextHelp() ) ) );
                       button[ButtonHelp]->setCursor(ArrowCursor);
@@ -343,7 +361,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
               case 'I': // Minimize button
                   if ((!button[ButtonMinimize]) && isMinimizable())  {
                       button[ButtonMinimize] = new QToolButton( widget(), 0 );
-                      QToolTip::add( button[ButtonMinimize], i18n("Minimize") );
+                      button[ButtonMinimize]->setToolTip( i18n("Minimize") );
                       button[ButtonMinimize]->setCursor(ArrowCursor);
                       button[ButtonMinimize]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
                       connect( button[ButtonMinimize], SIGNAL( clicked() ), this, ( SLOT( minimize() ) ) );
@@ -355,7 +373,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
                   if ((!button[ButtonMaximize]) && isMaximizable()) {
                       const bool max = maximizeMode()!=MaximizeRestore;
                       button[ButtonMaximize] = new ThreeButtonButton( widget(), 0 );
-                      QToolTip::add( button[ButtonMaximize], max?i18n("Restore"):i18n("Maximize") );
+                      button[ButtonMaximize]->setToolTip( max?i18n("Restore"):i18n("Maximize") );
                       button[ButtonMaximize]->setCursor(ArrowCursor);
                       button[ButtonMaximize]->setIconSet( max?(isActive() ? *normalize_pix : *dis_normalize_pix):(isActive() ? *maximize_pix : *dis_maximize_pix) );
                       connect( button[ButtonMaximize], SIGNAL( clicked(ButtonState) ),
@@ -367,7 +385,7 @@ void StdClient::addButtons(QBoxLayout *hb, const QString& s)
               case 'X': // Close button
                   if ((!button[ButtonClose]) && isCloseable()) {
                       button[ButtonClose] = new QToolButton( widget(), 0 );
-                      QToolTip::add( button[ButtonClose], i18n("Close") );
+                      button[ButtonClose]->setToolTip( i18n("Close") );
                       button[ButtonClose]->setCursor(ArrowCursor);
                       button[ButtonClose]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
                       connect( button[ButtonClose], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
@@ -441,7 +459,7 @@ void StdClient::maximizeChange()
     if (button[ButtonMaximize]) {
         button[ButtonMaximize]->setIconSet( m?*normalize_pix:*maximize_pix  );
         QToolTip::remove( button[ButtonMaximize] );
-        QToolTip::add( button[ButtonMaximize], m ? i18n("Restore") : i18n("Maximize") );
+        button[ButtonMaximize]->setToolTip( m ? i18n("Restore") : i18n("Maximize") );
     }
 }
 
@@ -454,7 +472,7 @@ void StdClient::desktopChange()
     if (button[ButtonSticky]) {
         button[ButtonSticky]->setIconSet( s?*pindown_pix:*pinup_pix );
         QToolTip::remove( button[ButtonSticky] );
-        QToolTip::add( button[ButtonSticky], s ? i18n("Not On All Desktops") : i18n("On All Desktops") );
+        button[ButtonSticky]->setToolTip( s ? i18n("Not On All Desktops") : i18n("On All Desktops") );
     }
 }
 
@@ -494,18 +512,11 @@ void StdClient::paintEvent( QPaintEvent* )
 
 void StdClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
 
-void StdClient::wheelEvent( QWheelEvent * e )
-{
-    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
-        titlebarMouseWheelOperation( e->delta());
-}
-
-
 void StdClient::iconChange()
 {
     if (button[ButtonMenu]) {
@@ -563,10 +574,6 @@ bool StdClient::eventFilter( QObject* o, QEvent* e )
 	processMousePressEvent( static_cast< QMouseEvent* >( e ) );
 	return true;
 
-    case QEvent::Wheel:
-	wheelEvent( static_cast< QWheelEvent* >( e ));
-	return true;
-
     default:
 	return false;
     }
@@ -613,7 +620,7 @@ void StdToolClient::init()
     g->addRowSpacing(2, 1);
 
     closeBtn = new QToolButton( widget(), 0 );
-    QToolTip::add( closeBtn, i18n("Close") );
+    closeBtn->setToolTip( i18n("Close") );
     connect( closeBtn, SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
     closeBtn->setFixedSize( 13, 13);
     reset( -1U );
@@ -665,16 +672,10 @@ void StdToolClient::paintEvent( QPaintEvent* )
 
 void StdToolClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
         titlebarDblClickOperation();
 }
 
-void StdToolClient::wheelEvent( QWheelEvent * e )
-{
-    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
-        titlebarMouseWheelOperation( e->delta());
-}
-
 void StdToolClient::captionChange()
 {
     widget()->repaint( titlebar->geometry(), FALSE );
@@ -712,10 +713,6 @@ bool StdToolClient::eventFilter( QObject* o, QEvent* e )
 	processMousePressEvent( static_cast< QMouseEvent* >( e ) );
 	return true;
 
-    case QEvent::Wheel:
-	wheelEvent( static_cast< QWheelEvent* >( e ));
-	return true;
-
     default:
 	return false;
     }
