@@ -29,6 +29,14 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qpainter.h>
+//Added by qt3to4:
+#include <QPaintEvent>
+#include <Q3PtrList>
+#include <QEvent>
+#include <QBoxLayout>
+#include <QResizeEvent>
+#include <QVBoxLayout>
+#include <QMouseEvent>
 
 #include <netwm.h>
 
@@ -97,9 +105,6 @@ bool Manager::eventFilter(QObject *o, QEvent *e)
       case QEvent::MouseButtonPress:
          processMousePressEvent(static_cast<QMouseEvent*>(e));
          return true;
-      case QEvent::Wheel:
-         wheelEvent( static_cast< QWheelEvent* >( e ));
-         return true;
       case QEvent::MouseButtonRelease:
          return false;
       case QEvent::Show:
@@ -311,7 +316,7 @@ void Manager::updateTitleBuffer()
    p.setFont(options()->font(active));
 
    p.drawText(4, 2, tr.width() - 8, Static::instance()->titleHeight() - 4,
-              AlignCenter, caption());
+              Qt::AlignCenter, caption());
 
    p.drawPixmap(tr.width() - 3, 0, s->titleTextRight(active));
 }
@@ -352,16 +357,10 @@ KDecoration::Position Manager::mousePosition(const QPoint& p) const
 
 void Manager::mouseDoubleClickEvent(QMouseEvent *e)
 {
-   if (e->button() == LeftButton && titleSpacer_->geometry().contains(e->pos()))
+   if (e->button() == Qt::LeftButton && titleSpacer_->geometry().contains(e->pos()))
       titlebarDblClickOperation();
 }
 
-void Manager::wheelEvent(QWheelEvent *e)
-{
-    if (isSetShade() || titleLayout_->geometry().contains(e->pos()) )
-        titlebarMouseWheelOperation( e->delta());
-}
-
 void Manager::paletteChange(const QPalette &)
 {
    resetLayout();
@@ -388,28 +387,9 @@ void Manager::slotLower()
    setKeepBelow(!keepBelow());
 }
 
-void Manager::slotMaximizeClicked(ButtonState state)
+void Manager::slotMaximizeClicked(Qt::MouseButton state)
 {
-#if KDE_IS_VERSION(3, 3, 0)
    maximize(state);
-#else
-   switch (state)
-   {
-      case RightButton:
-         maximize(maximizeMode() ^ MaximizeHorizontal);
-         break;
-
-      case MidButton:
-         maximize(maximizeMode() ^ MaximizeVertical);
-         break;
-
-      case LeftButton:
-      default:
-         maximize(maximizeMode() == MaximizeFull ? MaximizeRestore
-                                                 : MaximizeFull);
-         break;
-   }
-#endif
    emit(maximizeChanged(maximizeMode() == MaximizeFull));
 }
 
@@ -602,7 +582,7 @@ void Manager::createTitle()
    else
       buttons = "XSH|IA";
 
-   QPtrList<Button> *buttonList = &leftButtonList_;
+   Q3PtrList<Button> *buttonList = &leftButtonList_;
 
    for (unsigned int i = 0; i < buttons.length(); ++i)
    {
@@ -638,8 +618,8 @@ void Manager::createTitle()
             if (isMaximizable())
             {
                tb = new MaximiseButton(widget());
-               connect(tb, SIGNAL(maximizeClicked(ButtonState)),
-                       this, SLOT(slotMaximizeClicked(ButtonState)));
+               connect(tb, SIGNAL(maximizeClicked(MouseButton)),
+                       this, SLOT(slotMaximizeClicked(MouseButton)));
                connect(this, SIGNAL(maximizeChanged(bool)),
                        tb, SLOT(setOn(bool)));
                emit(maximizeChanged(maximizeMode() == MaximizeFull));
@@ -676,7 +656,7 @@ void Manager::createTitle()
       }
    }
 
-   for (QPtrListIterator<Button> it(leftButtonList_); it.current(); ++it)
+   for (Q3PtrListIterator<Button> it(leftButtonList_); it.current(); ++it)
    {
       it.current()->setAlignment(Button::Left);
       titleLayout_->addWidget(it.current());
@@ -687,7 +667,7 @@ void Manager::createTitle()
 
    titleLayout_->addItem(titleSpacer_);
 
-   for (QPtrListIterator<Button> it(rightButtonList_); it.current(); ++it)
+   for (Q3PtrListIterator<Button> it(rightButtonList_); it.current(); ++it)
    {
       it.current()->setAlignment(Button::Right);
       titleLayout_->addWidget(it.current());
